#!/usr/bin/env perl

use strict;
use warnings;

use Test::More;

use Bio::EnsEMBL::Test::MultiTestDB;
use Bio::EnsEMBL::Test::TestUtils;

#####################################################################
## Connect to the test database using the MultiTestDB.conf file

my $multi = Bio::EnsEMBL::Test::MultiTestDB->new( "multi" );
my $compara_db_adaptor = $multi->get_DBAdaptor( "compara" );
my $genome_db_adaptor = $compara_db_adaptor->get_GenomeDBAdaptor();

my $homo_sapiens = Bio::EnsEMBL::Test::MultiTestDB->new("homo_sapiens");

my $hs_dba = $homo_sapiens->get_DBAdaptor('core');

##
#####################################################################

#
# Compiles
#
ok(1);

my $dbID = 1;
my $taxon_id = 9606;
my $name = "Homo sapiens";
my $assembly = "NCBI36";
my $genebuild = "0510Ensembl";

subtest "Test Bio::EnsEMBL::Compara::GenomeDB new(void)", sub {

    my $genome_db = Bio::EnsEMBL::Compara::GenomeDB->new();
    isa_ok($genome_db, "Bio::EnsEMBL::Compara::GenomeDB", "check object");
    done_testing();
};

subtest "Test Bio::EnsEMBL::Compara::GenomeDB new(ALL) method", sub {
    my $genome_db = Bio::EnsEMBL::Compara::GenomeDB->new(
                                                         -dbID => $dbID,
                                                         -db_adaptor => $hs_dba,
                                                         -name => $name,
                                                         -assembly => $assembly,
                                                         -taxon_id => $taxon_id,
                                                         -genebuild => $genebuild
                                                        );

    $genome_db->adaptor($genome_db_adaptor);

    is($genome_db->db_adaptor, $hs_dba, "Testing dba set in new method");
    is($genome_db->name, $name, "Testing name set in new method");
    is($genome_db->assembly, $assembly, "Testing assembly set in new method");
    is($genome_db->taxon_id, $taxon_id, "Testing taxon_id set in new method");
    is($genome_db->dbID, $dbID, "Testing dbID set in new method");
    is($genome_db->genebuild, $genebuild, "Testing genebuild set in new method");

    is($genome_db->taxon->name, $name);
    done_testing();
};

#Test new_fast method
subtest "Test Bio::EnsEMBL::Compara::GenomeDB new_fast method", sub {
    my $genome_db_hash;
    %$genome_db_hash = ('adaptor' => $genome_db_adaptor,
                        '_db_adaptor' => $hs_dba,
                        'name'       => $name,
                        'assembly'   => $assembly,
                        'taxon_id'   => $taxon_id,
                        'dbID'       => $dbID,
                        'genebuild'  => $genebuild);
    
    my $genome_db = new_fast Bio::EnsEMBL::Compara::GenomeDB($genome_db_hash);
    
    is($genome_db->db_adaptor, $hs_dba, "Testing dba set in new method");
    is($genome_db->name, $name, "Testing name set in new method");
    is($genome_db->assembly, $assembly, "Testing assembly set in new method");
    is($genome_db->taxon_id, $taxon_id, "Testing taxon_id set in new method");
    is($genome_db->dbID, $dbID, "Testing dbID set in new method");
    is($genome_db->genebuild, $genebuild, "Testing genebuild set in new method");
    
    is($genome_db->taxon->name, $name);
    done_testing();
};

done_testing();
